@@ -1,12 +1,12 @@
 from __future__ import annotations
 
-import os
 import warnings
 from logging import getLogger
 
 import questionary
 
-from commitizen import bump, cmd, factory, git, hooks, out
+from commitizen import bump, factory, git, hooks, out
+from commitizen.changelog_formats import get_changelog_format
 from commitizen.commands.changelog import Changelog
 from commitizen.config import BaseConfig
 from commitizen.exceptions import (
@@ -14,6 +14,7 @@ from commitizen.exceptions import (
     BumpTagFailedError,
     DryRunExit,
     ExpectedExit,
+    GetNextExit,
     InvalidManualVersion,
     NoCommitsFoundError,
     NoneIncrementExit,
@@ -22,13 +23,12 @@ from commitizen.exceptions import (
     NotAllowed,
     NoVersionSpecifiedError,
 )
-from commitizen.changelog_formats import get_changelog_format
 from commitizen.providers import get_provider
 from commitizen.version_schemes import (
-    get_version_scheme,
     Increment,
     InvalidVersion,
     Prerelease,
+    get_version_scheme,
 )
 
 logger = getLogger("commitizen")
@@ -160,6 +160,7 @@ class Bump:
         manual_version = self.arguments["manual_version"]
         build_metadata = self.arguments["build_metadata"]
         increment_mode: str = self.arguments["increment_mode"]
+        get_next: bool = self.arguments["get_next"]
 
         if manual_version:
             if increment:
@@ -191,6 +192,9 @@ class Bump:
                     "--prerelease-offset cannot be combined with MANUAL_VERSION"
                 )
 
+            if get_next:
+                raise NotAllowed("--get-next cannot be combined with MANUAL_VERSION")
+
         if major_version_zero:
             if not current_version.release[0] == 0:
                 raise NotAllowed(
@@ -203,6 +207,18 @@ class Bump:
                     "--local-version cannot be combined with --build-metadata"
                 )
 
+        # If user specified changelog_to_stdout, they probably want the
+        # changelog to be generated as well, this is the most intuitive solution
+        self.changelog = self.changelog or bool(self.changelog_to_stdout)
+
+        if get_next:
+            if self.changelog:
+                raise NotAllowed(
+                    "--changelog or --changelog-to-stdout is not allowed with --get-next"
+                )
+            # Setting dry_run to prevent any unwanted changes to the repo or files
+            self.dry_run = True
+
         current_tag_version: str = bump.normalize_tag(
             current_version,
             tag_format=tag_format,
@@ -211,10 +227,6 @@ class Bump:
 
         is_initial = self.is_initial_tag(current_tag_version, is_yes)
 
-        # If user specified changelog_to_stdout, they probably want the
-        # changelog to be generated as well, this is the most intuitive solution
-        self.changelog = self.changelog or bool(self.changelog_to_stdout)
-
         if manual_version:
             try:
                 new_version = self.scheme(manual_version)
@@ -267,6 +279,16 @@ class Bump:
             current_version, new_version, bump_commit_message
         )
 
+        if get_next:
+            if increment is None and new_tag_version == current_tag_version:
+                raise NoneIncrementExit(
+                    "[NO_COMMITS_TO_BUMP]\n"
+                    "The commits found are not eligible to be bumped"
+                )
+
+            out.write(str(new_version))
+            raise GetNextExit()
+
         # Report found information
         information = f"{message}\n" f"tag to create: {new_tag_version}\n"
         if increment:
@@ -286,56 +308,39 @@ class Bump:
                 "The commits found are not eligible to be bumped"
             )
 
+        files: list[str] = []
         if self.changelog:
+            args = {
+                "unreleased_version": new_tag_version,
+                "template": self.template,
+                "extras": self.extras,
+                "incremental": True,
+                "dry_run": dry_run,
+            }
             if self.changelog_to_stdout:
-                changelog_cmd = Changelog(
-                    self.config,
-                    {
-                        "unreleased_version": new_tag_version,
-                        "template": self.template,
-                        "extras": self.extras,
-                        "incremental": True,
-                        "dry_run": True,
-                    },
-                )
+                changelog_cmd = Changelog(self.config, {**args, "dry_run": True})
                 try:
                     changelog_cmd()
                 except DryRunExit:
                     pass
-            changelog_cmd = Changelog(
-                self.config,
-                {
-                    "unreleased_version": new_tag_version,
-                    "incremental": True,
-                    "dry_run": dry_run,
-                    "template": self.template,
-                    "extras": self.extras,
-                    "file_name": self.file_name,
-                },
-            )
+
+            args["file_name"] = self.file_name
+            changelog_cmd = Changelog(self.config, args)
             changelog_cmd()
-            file_names = []
-            for file_name in version_files:
-                drive, tail = os.path.splitdrive(file_name)
-                path, _, regex = tail.partition(":")
-                path = drive + path if path != "" else drive + regex
-                file_names.append(path)
-            git_add_changelog_and_version_files_command = (
-                f"git add {changelog_cmd.file_name} "
-                f"{' '.join(name for name in file_names)}"
-            )
-            c = cmd.run(git_add_changelog_and_version_files_command)
+            files.append(changelog_cmd.file_name)
 
         # Do not perform operations over files or git.
         if dry_run:
             raise DryRunExit()
 
-        bump.update_version_in_files(
-            str(current_version),
-            str(new_version),
-            version_files,
-            check_consistency=self.check_consistency,
-            encoding=self.encoding,
+        files.extend(
+            bump.update_version_in_files(
+                str(current_version),
+                str(new_version),
+                version_files,
+                check_consistency=self.check_consistency,
+                encoding=self.encoding,
+            )
         )
 
         provider.set_version(str(new_version))
@@ -358,12 +363,13 @@ class Bump:
             raise ExpectedExit()
 
         # FIXME: check if any changes have been staged
+        git.add(*files)
         c = git.commit(message, args=self._get_commit_args())
         if self.retry and c.return_code != 0 and self.changelog:
             # Maybe pre-commit reformatted some files? Retry once
             logger.debug("1st git.commit error: %s", c.err)
             logger.info("1st commit attempt failed; retrying once")
-            cmd.run(git_add_changelog_and_version_files_command)
+            git.add(*files)
             c = git.commit(message, args=self._get_commit_args())
         if c.return_code != 0:
             err = c.err.strip() or c.out
