@@ -134,17 +134,18 @@ class Commit:
         if dry_run:
             raise DryRunExit()
 
-        signoff: bool = (
-            self.arguments.get("signoff") or self.config.settings["always_signoff"]
-        )
+        always_signoff: bool = self.config.settings["always_signoff"]
+        signoff: bool = self.arguments.get("signoff")
+
+        extra_args = self.arguments.get("extra_cli_args", "")
 
         if signoff:
             out.warn(
                 "signoff mechanic is deprecated, please use `cz commit -- -s` instead."
             )
-            extra_args = self.arguments.get("extra_cli_args", "--") + " -s"
-        else:
-            extra_args = self.arguments.get("extra_cli_args", "")
+
+        if always_signoff or signoff:
+            extra_args = f"{extra_args} -s".strip()
 
         c = git.commit(m, args=extra_args)
 
