@@ -17,6 +17,12 @@ class MessageBuilderHook(Protocol):
     ) -> dict[str, Any] | Iterable[dict[str, Any]] | None: ...
 
 
+class ChangelogReleaseHook(Protocol):
+    def __call__(
+        self, release: dict[str, Any], tag: git.GitTag | None
+    ) -> dict[str, Any]: ...
+
+
 class BaseCommitizen(metaclass=ABCMeta):
     bump_pattern: str | None = None
     bump_map: dict[str, str] | None = None
@@ -48,11 +54,14 @@ class BaseCommitizen(metaclass=ABCMeta):
     # Executed only at the end of the changelog generation
     changelog_hook: Callable[[str, str | None], str] | None = None
 
+    # Executed for each release in the changelog
+    changelog_release_hook: ChangelogReleaseHook | None = None
+
     # Plugins can override templates and provide extra template data
     template_loader: BaseLoader = PackageLoader("commitizen", "templates")
     template_extras: dict[str, Any] = {}
 
-    def __init__(self, config: BaseConfig):
+    def __init__(self, config: BaseConfig) -> None:
         self.config = config
         if not self.config.settings.get("style"):
             self.config.settings.update({"style": BaseCommitizen.default_style_config})
@@ -74,19 +83,19 @@ class BaseCommitizen(metaclass=ABCMeta):
             ]
         )
 
-    def example(self) -> str | None:
+    def example(self) -> str:
         """Example of the commit message."""
         raise NotImplementedError("Not Implemented yet")
 
-    def schema(self) -> str | None:
+    def schema(self) -> str:
         """Schema definition of the commit message."""
         raise NotImplementedError("Not Implemented yet")
 
-    def schema_pattern(self) -> str | None:
+    def schema_pattern(self) -> str:
         """Regex matching the schema used for message validation."""
         raise NotImplementedError("Not Implemented yet")
 
-    def info(self) -> str | None:
+    def info(self) -> str:
         """Information about the standardized commit message."""
         raise NotImplementedError("Not Implemented yet")
 
